sr = 44100
kr = 44100
ksmps = 1
nchnls = 2

/********************************************************
		Sntesis de voces corales
		       mediante CSound
	Autor: Jos Javier Valero Mas

	Tutor: Jos Manuel Iesta Quereda
********************************************************/



/********************************************************
		NUMERACIN DE INSTRUMENTOS
********************************************************/
/*EXCITADORES: 1001 --> Soprano
	       1002 --> Contralto
	       1003 --> Tenor
	       1004 --> Bartono

FILTROS VOCALES: x01 --> /a/
		 x05 --> /e/
		 x09 --> /i/
		 x15 --> /o/
		 x21 --> /u/

CONSONANTES: Su posicin en ASCII relativa a la 'a'
*/


;-------- GLOBAL VARIABLES INITIALIZATION: VOICE DRIVERS + REVERB

gasoprano init 0
gaalto    init 0
gatenor   init 0
gabajo    init 0
gareverb  init 0

;----------------------------------------------- SOPRANO

instr 1001	; Pulse wave source for soprano voices.

        idur = p3
        iamp = ampdb(p5)
        ifreq = cpspch(p4)

        iharms=(sr*.4) / ifreq

        asig    gbuzz   1, ifreq, iharms, 1, .8, 2
        kenv    linseg  0, .1, iamp, idur -.2, iamp, .1, 0
        aout = kenv * asig
        gasoprano = gasoprano + aout
endin

;----------------------------------------------- CONTRAALTO

instr 1002 ; Pulse wave source for soprano voices.

        idur = p3
        iamp = ampdb(p5)
        ifreq = cpspch(p4)

        iharms=(sr*.4) / ifreq

        asig    gbuzz   1, ifreq, iharms, 1, .8, 2
        kenv    linseg  0, .1, iamp, idur -.2, iamp, .1, 0
        aout = kenv * asig
        gaalto = gaalto + aout

endin

;----------------------------------------------- TENOR
instr 1003	; Pulse wave source for tenor voices.
		; Octave lower than soprano.

        idur = p3
        iamp = ampdb(p5)
        ifreq = cpspch(p4) * .5

        iharms=(sr*.4) / ifreq

        asig    gbuzz   1, ifreq, iharms, 1, .9, 2
        kenv    linseg  0, .1, iamp, idur -.2, iamp, .1, 0
        aout = kenv * asig
        gatenor = gatenor + aout

endin

;----------------------------------------------- BAJO
instr 1004
        idur = p3
        iamp = ampdb(p5)
        ifreq = cpspch(p4) * .5

        iharms=(sr*.4) / ifreq

        asig    gbuzz   1, ifreq, iharms, 1, .9, 2
        kenv    linseg  0, .1, iamp, idur -.2, iamp, .1, 0
        aout = kenv * asig
        gabajo = gabajo + aout
endin

;----------------------------------------------- FORMANTES SOPRANO A
instr 101        ; Global animator/formants for soprano

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4, 1
        ktime2  oscili  .0009 * kvib, 5, 1
        ktime3  oscili  .00087 * kvib, 6.3, 1
        ktime4  oscili  .0011 * kvib, 4.4, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gasoprano

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; the soprano "ah" sound.
        afilt_sa1  reson   aout, 800, 80, 1
        afilt_sa2  resonz  aout, 1150, 90, 1
        afilt_sa3  resonz  aout, 2900, 120, 1
        afilt_sa4  resonz  aout, 3900, 130, 1
        afilt_sa5  resonz  aout, 4950, 140, 1

        iamp1 = 0
        iamp2 = ampdb(70-6)
        iamp3 = ampdb(70-32)
        iamp4 = ampdb(70-20)
        iamp5 = ampdb(70-50)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        ;aout2 = (afilt_sa1 + .5 * afilt_sa2 + 0.1 * afilt_sa3 + 0.3 * afilt_sa4 + .05 * afilt_sa5)
        aout2 = (afilt_sa1 + ip2 * afilt_sa2 + ip3 * afilt_sa3 + ip4 * afilt_sa4 + ip5 * afilt_sa5)
	aout2 = aout2 * kenv

        ; Part of output sent to reverb.
        gareverb = gareverb + .47 * aout2

        outs    aout2, aout2

        gasoprano = 0

endin

;----------------------------------------------- FORMANTES SOPRANO E
instr 105        ; Global animator/formants for soprano

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4, 1
        ktime2  oscili  .0009 * kvib, 5, 1
        ktime3  oscili  .00087 * kvib, 6.3, 1
        ktime4  oscili  .0011 * kvib, 4.4, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gasoprano

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; the soprano "Eh" sound.
        afilt_se1  reson   aout, 350, 60, 1
        afilt_se2  resonz  aout, 2000, 100, 1
        afilt_se3  resonz  aout, 2800, 120, 1
        afilt_se4  resonz  aout, 3600, 150, 1
        afilt_se5  resonz  aout, 4950, 200, 1

        iamp1 = 0
        iamp2 = ampdb(70-20)
        iamp3 = ampdb(70-15)
        iamp4 = ampdb(70-40)
        iamp5 = ampdb(70-56)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        ;aout2 = (afilt_sa1 + .5 * afilt_sa2 + 0.1 * afilt_sa3 + 0.3 * afilt_sa4 + .05 * afilt_sa5)
        aout2 = (afilt_se1 + ip2 * afilt_se2 + ip3 * afilt_se3 + ip4 * afilt_se4 + ip5 * afilt_se5)
	aout2 = aout2 * kenv

        ; Part of output sent to reverb.
        gareverb = gareverb + .47 * aout2

        outs    aout2, aout2

        gasoprano = 0

endin

;----------------------------------------------- FORMANTES SOPRANO I
instr 109        ; Global animator/formants for soprano

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4, 1
        ktime2  oscili  .0009 * kvib, 5, 1
        ktime3  oscili  .00087 * kvib, 6.3, 1
        ktime4  oscili  .0011 * kvib, 4.4, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gasoprano

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; the soprano "Ih" sound.
        afilt1  reson   aout, 270, 60, 1
        afilt2  resonz  aout, 2140, 90, 1
        afilt3  resonz  aout, 2950, 100, 1
        afilt4  resonz  aout, 3900, 120, 1
        afilt5  resonz  aout, 4950, 120, 1

        iamp1 = 0
        iamp2 = ampdb(70-12)
        iamp3 = ampdb(70-26)
        iamp4 = ampdb(70-26)
        iamp5 = ampdb(70-44)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        ;aout2 = (afilt_sa1 + .5 * afilt_sa2 + 0.1 * afilt_sa3 + 0.3 * afilt_sa4 + .05 * afilt_sa5)
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv
        ; Part of output sent to reverb.
        gareverb = gareverb + .47 * aout2

        outs    aout2, aout2

        gasoprano = 0

endin

;----------------------------------------------- FORMANTES SOPRANO O
instr 115        ; Global animator/formants for soprano

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4, 1
        ktime2  oscili  .0009 * kvib, 5, 1
        ktime3  oscili  .00087 * kvib, 6.3, 1
        ktime4  oscili  .0011 * kvib, 4.4, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gasoprano

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; the soprano "Oh" sound.
        afilt1  reson   aout, 450, 70, 1
        afilt2  resonz  aout, 800, 80, 1
        afilt3  resonz  aout, 2830, 100, 1
        afilt4  resonz  aout, 3800, 130, 1
        afilt5  resonz  aout, 4950, 135, 1

        iamp1 = 0
        iamp2 = ampdb(70-11)
        iamp3 = ampdb(70-22)
        iamp4 = ampdb(70-22)
        iamp5 = ampdb(70-50)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        ;aout2 = (afilt_sa1 + .5 * afilt_sa2 + 0.1 * afilt_sa3 + 0.3 * afilt_sa4 + .05 * afilt_sa5)
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Part of output sent to reverb.
        gareverb = gareverb + .47 * aout2

        outs    aout2, aout2

        gasoprano = 0

endin


;----------------------------------------------- FORMANTES SOPRANO U
instr 121        ; Global animator/formants for soprano

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4, 1
        ktime2  oscili  .0009 * kvib, 5, 1
        ktime3  oscili  .00087 * kvib, 6.3, 1
        ktime4  oscili  .0011 * kvib, 4.4, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gasoprano

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; the soprano "Uh" sound.
        afilt1  reson   aout, 325, 85, 1
        afilt2  resonz  aout, 700, 60, 1
        afilt3  resonz  aout, 2700, 170, 1
        afilt4  resonz  aout, 3800, 180, 1
        afilt5  resonz  aout, 4950, 200, 1

        iamp1 = 0
        iamp2 = ampdb(70-16)
        iamp3 = ampdb(70-35)
        iamp4 = ampdb(70-40)
        iamp5 = ampdb(70-60)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        ;aout2 = (afilt_sa1 + .5 * afilt_sa2 + 0.1 * afilt_sa3 + 0.3 * afilt_sa4 + .05 * afilt_sa5)
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Part of output sent to reverb.
        gareverb = gareverb + .47 * aout2

        outs    aout2, aout2

        gasoprano = 0

endin

;----------------------------------------------- FORMANTES CONTRAALTO A
instr 201        ; Global animator/formants for contraalto
        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4, 1
        ktime2  oscili  .0009 * kvib, 5, 1
        ktime3  oscili  .00087 * kvib, 6.3, 1
        ktime4  oscili  .0011 * kvib, 4.4, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gaalto

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; the contraalto "ah" sound.
        afilt1  reson   aout, 800, 80, 1
        afilt2  resonz  aout, 1150, 90, 1
        afilt3  resonz  aout, 2800, 120, 1
        afilt4  resonz  aout, 3500, 130, 1
        afilt5  resonz  aout, 4950, 140, 1

        iamp1 = 0
        iamp2 = ampdb(70-4)
        iamp3 = ampdb(70-20)
        iamp4 = ampdb(70-36)
        iamp5 = ampdb(70-60)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        ;aout2 = (afilt_sa1 + .5 * afilt_sa2 + 0.1 * afilt_sa3 + 0.3 * afilt_sa4 + .05 * afilt_sa5)
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Part of output sent to reverb.
        gareverb = gareverb + .47 * aout2

        outs    aout2, aout2

        gaalto = 0

endin

;----------------------------------------------- FORMANTES CONTRAALTO E
instr 205        ; Global animator/formants for contraalto

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4, 1
        ktime2  oscili  .0009 * kvib, 5, 1
        ktime3  oscili  .00087 * kvib, 6.3, 1
        ktime4  oscili  .0011 * kvib, 4.4, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gaalto

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; the contraalto "Eh" sound.
        afilt1  reson   aout, 400, 60, 1
        afilt2  resonz  aout, 1600, 80, 1
        afilt3  resonz  aout, 2700, 120, 1
        afilt4  resonz  aout, 3300, 150, 1
        afilt5  resonz  aout, 4950, 200, 1

        iamp1 = 0
        iamp2 = ampdb(70-24)
        iamp3 = ampdb(70-30)
        iamp4 = ampdb(70-35)
        iamp5 = ampdb(70-60)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        ;aout2 = (afilt_sa1 + .5 * afilt_sa2 + 0.1 * afilt_sa3 + 0.3 * afilt_sa4 + .05 * afilt_sa5)
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Part of output sent to reverb.
        gareverb = gareverb + .47 * aout2

        outs    aout2, aout2

        gaalto = 0

endin

;----------------------------------------------- FORMANTES CONTRAALTO I
instr 209        ; Global animator/formants for contraalto

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4, 1
        ktime2  oscili  .0009 * kvib, 5, 1
        ktime3  oscili  .00087 * kvib, 6.3, 1
        ktime4  oscili  .0011 * kvib, 4.4, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gaalto

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; the contraalto "Ih" sound.
        afilt1  reson   aout, 350, 50, 1
        afilt2  resonz  aout, 1700, 100, 1
        afilt3  resonz  aout, 2700, 120, 1
        afilt4  resonz  aout, 3700, 150, 1
        afilt5  resonz  aout, 4950, 200, 1

        iamp1 = 0
        iamp2 = ampdb(70-20)
        iamp3 = ampdb(70-30)
        iamp4 = ampdb(70-36)
        iamp5 = ampdb(70-60)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        ;aout2 = (afilt_sa1 + .5 * afilt_sa2 + 0.1 * afilt_sa3 + 0.3 * afilt_sa4 + .05 * afilt_sa5)
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Part of output sent to reverb.
        gareverb = gareverb + .47 * aout2

        outs    aout2, aout2

        gaalto = 0

endin

;----------------------------------------------- FORMANTES CONTRAALTO O
instr 215        ; Global animator/formants for contraalto

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4, 1
        ktime2  oscili  .0009 * kvib, 5, 1
        ktime3  oscili  .00087 * kvib, 6.3, 1
        ktime4  oscili  .0011 * kvib, 4.4, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gaalto

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; the contraalto "Oh" sound.
        afilt1  reson   aout, 450, 70, 1
        afilt2  resonz  aout, 800, 80, 1
        afilt3  resonz  aout, 2830, 100, 1
        afilt4  resonz  aout, 3500, 130, 1
        afilt5  resonz  aout, 4950, 135, 1

        iamp1 = 0
        iamp2 = ampdb(70-9)
        iamp3 = ampdb(70-16)
        iamp4 = ampdb(70-28)
        iamp5 = ampdb(70-55)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        ;aout2 = (afilt_sa1 + .5 * afilt_sa2 + 0.1 * afilt_sa3 + 0.3 * afilt_sa4 + .05 * afilt_sa5)
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Part of output sent to reverb.
        gareverb = gareverb + .47 * aout2

        outs    aout2, aout2

        gaalto = 0

endin


;----------------------------------------------- FORMANTES CONTRAALTO U
instr 221        ; Global animator/formants for contraalto

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4, 1
        ktime2  oscili  .0009 * kvib, 5, 1
        ktime3  oscili  .00087 * kvib, 6.3, 1
        ktime4  oscili  .0011 * kvib, 4.4, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gaalto

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; the contraalto "Uh" sound.
        afilt1  reson   aout, 325, 50, 1
        afilt2  resonz  aout, 700, 60, 1
        afilt3  resonz  aout, 2530, 170, 1
        afilt4  resonz  aout, 3500, 180, 1
        afilt5  resonz  aout, 4950, 200, 1

        iamp1 = 0
        iamp2 = ampdb(70-12)
        iamp3 = ampdb(70-30)
        iamp4 = ampdb(70-40)
        iamp5 = ampdb(70-64)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        ;aout2 = (afilt_sa1 + .5 * afilt_sa2 + 0.1 * afilt_sa3 + 0.3 * afilt_sa4 + .05 * afilt_sa5)
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Part of output sent to reverb.
        gareverb = gareverb + .47 * aout2

        outs    aout2, aout2

        gaalto = 0

endin


;----------------------------------------------- FORMANTES TENOR
instr 301        ; Global animator/formants for tenor VOCAL A

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4.2, 1
        ktime2  oscili  .0009 * kvib, 5.3, 1
        ktime3  oscili  .00087 * kvib, 6.1, 1
        ktime4  oscili  .0011 * kvib, 3.9, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gatenor

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; the tenor "ah" sound.
        afilt1  reson   aout, 650, 80, 1
        afilt2  resonz  aout, 1080, 90, 1
        afilt3  resonz  aout, 2650, 120, 1
        afilt4  resonz  aout, 2900, 130, 1
        afilt5  resonz  aout, 3250, 140, 1
        iamp1 = 0
        iamp2 = ampdb(70-6)
        iamp3 = ampdb(70-7)
        iamp4 = ampdb(70-8)
        iamp5 = ampdb(70-22)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        gareverb = gareverb + .47 * aout2

        ; Part of output sent to reverb.
        outs    aout2, aout2

        gatenor = 0

endin

instr 305        ; Global animator/formants for tenor VOCAL E

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4.2, 1
        ktime2  oscili  .0009 * kvib, 5.3, 1
        ktime3  oscili  .00087 * kvib, 6.1, 1
        ktime4  oscili  .0011 * kvib, 3.9, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gatenor

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Cantando e
        afilt1  reson   aout, 400, 70, 1
        afilt2  resonz  aout, 1700, 80, 1
        afilt3  resonz  aout, 2600, 100, 1
        afilt4  resonz  aout, 3200, 120, 1
        afilt5  resonz  aout, 3580, 120, 1
        iamp1 = 0
        iamp2 = ampdb(70-14)
        iamp3 = ampdb(70-12)
        iamp4 = ampdb(70-14)
        iamp5 = ampdb(70-20)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        gareverb = gareverb + .47 * aout2

        ; Part of output sent to reverb.
        outs    aout2, aout2

        gatenor = 0

endin

instr 309        ; Global animator/formants for tenor VOCAL I

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4.2, 1
        ktime2  oscili  .0009 * kvib, 5.3, 1
        ktime3  oscili  .00087 * kvib, 6.1, 1
        ktime4  oscili  .0011 * kvib, 3.9, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gatenor

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Cantando i
        afilt1  reson   aout, 290, 40, 1
        afilt2  resonz  aout, 1870, 90, 1
        afilt3  resonz  aout, 2800, 100, 1
        afilt4  resonz  aout, 3250, 120, 1
        afilt5  resonz  aout, 3540, 120, 1
        iamp1 = 0
        iamp2 = ampdb(70-15)
        iamp3 = ampdb(70-18)
        iamp4 = ampdb(70-20)
        iamp5 = ampdb(70-30)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        gareverb = gareverb + .47 * aout2

        ; Part of output sent to reverb.
        outs    aout2, aout2

        gatenor = 0

endin

instr 315        ; Global animator/formants for tenor VOCAL O

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4.2, 1
        ktime2  oscili  .0009 * kvib, 5.3, 1
        ktime3  oscili  .00087 * kvib, 6.1, 1
        ktime4  oscili  .0011 * kvib, 3.9, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gatenor

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; Cantando o
        afilt1  reson   aout, 400, 40, 1
        afilt2  resonz  aout, 800, 80, 1
        afilt3  resonz  aout, 2600, 100, 1
        afilt4  resonz  aout, 2800, 120, 1
        afilt5  resonz  aout, 3000, 120, 1
        iamp1 = 0
        iamp2 = ampdb(70-10)
        iamp3 = ampdb(70-12)
        iamp4 = ampdb(70-12)
        iamp5 = ampdb(70-26)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        gareverb = gareverb + .47 * aout2

        ; Part of output sent to reverb.
        outs    aout2, aout2

        gatenor = 0

endin


instr 321        ; Global animator/formants for tenor VOCAL U

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4.2, 1
        ktime2  oscili  .0009 * kvib, 5.3, 1
        ktime3  oscili  .00087 * kvib, 6.1, 1
        ktime4  oscili  .0011 * kvib, 3.9, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gatenor

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; Cantando u
        afilt1  reson   aout, 350, 40, 1
        afilt2  resonz  aout, 600, 60, 1
        afilt3  resonz  aout, 2700, 100, 1
        afilt4  resonz  aout, 2900, 120, 1
        afilt5  resonz  aout, 3030, 120, 1
        iamp1 = 0
        iamp2 = ampdb(70-20)
        iamp3 = ampdb(70-17)
        iamp4 = ampdb(70-14)
        iamp5 = ampdb(70-26)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        gareverb = gareverb + .47 * aout2

        ; Part of output sent to reverb.
        outs    aout2, aout2

        gatenor = 0

endin


;----------------------------------------------- FORMANTES BAJO
instr 401        ; Global animator/formants for bajo VOCAL A

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4.2, 1
        ktime2  oscili  .0009 * kvib, 5.3, 1
        ktime3  oscili  .00087 * kvib, 6.1, 1
        ktime4  oscili  .0011 * kvib, 3.9, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gabajo

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; the bajo "ah" sound.
        afilt1  reson   aout, 600, 60, 1
        afilt2  resonz  aout, 1040, 70, 1
        afilt3  resonz  aout, 2250, 110, 1
        afilt4  resonz  aout, 2450, 120, 1
        afilt5  resonz  aout, 2750, 130, 1
        iamp1 = 0
        iamp2 = ampdb(70-7)
        iamp3 = ampdb(70-9)
        iamp4 = ampdb(70-9)
        iamp5 = ampdb(70-20)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        gareverb = gareverb + .47 * aout2

        ; Part of output sent to reverb.
        outs    aout2, aout2

        gabajo = 0
endin

instr 405        ; Global animator/formants for bajo VOCAL E

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4.2, 1
        ktime2  oscili  .0009 * kvib, 5.3, 1
        ktime3  oscili  .00087 * kvib, 6.1, 1
        ktime4  oscili  .0011 * kvib, 3.9, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gabajo

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Cantando e
        afilt1  reson   aout, 400, 40, 1
        afilt2  resonz  aout, 1620, 80, 1
        afilt3  resonz  aout, 2400, 100, 1
        afilt4  resonz  aout, 2800, 120, 1
        afilt5  resonz  aout, 3100, 120, 1
        iamp1 = 0
        iamp2 = ampdb(70-12)
        iamp3 = ampdb(70-9)
        iamp4 = ampdb(70-12)
        iamp5 = ampdb(70-18)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        gareverb = gareverb + .47 * aout2

        ; Part of output sent to reverb.
        outs    aout2, aout2

        gabajo = 0

endin

instr 409        ; Global animator/formants for bajo VOCAL I

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4.2, 1
        ktime2  oscili  .0009 * kvib, 5.3, 1
        ktime3  oscili  .00087 * kvib, 6.1, 1
        ktime4  oscili  .0011 * kvib, 3.9, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gabajo

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Cantando i
        afilt1  reson   aout, 250, 60, 1
        afilt2  resonz  aout, 1750, 90, 1
        afilt3  resonz  aout, 2600, 100, 1
        afilt4  resonz  aout, 3050, 120, 1
        afilt5  resonz  aout, 3340, 120, 1
        iamp1 = 0
        iamp2 = ampdb(70-30)
        iamp3 = ampdb(70-16)
        iamp4 = ampdb(70-22)
        iamp5 = ampdb(70-28)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        gareverb = gareverb + .47 * aout2

        ; Part of output sent to reverb.
        outs    aout2, aout2

        gabajo = 0

endin

instr 415        ; Global animator/formants for bajo VOCAL O

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4.2, 1
        ktime2  oscili  .0009 * kvib, 5.3, 1
        ktime3  oscili  .00087 * kvib, 6.1, 1
        ktime4  oscili  .0011 * kvib, 3.9, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gabajo

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; Cantando o
        afilt1  reson   aout, 400, 40, 1
        afilt2  resonz  aout, 750, 80, 1
        afilt3  resonz  aout, 2400, 100, 1
        afilt4  resonz  aout, 2600, 120, 1
        afilt5  resonz  aout, 2900, 120, 1
        iamp1 = 0
        iamp2 = ampdb(70-11)
        iamp3 = ampdb(70-21)
        iamp4 = ampdb(70-20)
        iamp5 = ampdb(70-40)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        gareverb = gareverb + .47 * aout2

        ; Part of output sent to reverb.
        outs    aout2, aout2

        gabajo = 0

endin


instr 421        ; Global animator/formants for bajo VOCAL U

        idur = p3
        ivib1 = p4
        ivib2 = p5
        ivibtime = p6

	kenv linen 1, 0.01*idur, idur, 0.01*idur

        kvib    linseg  ivib1, ivibtime, ivib1, idur, ivib2
        ; Four independent LFOs for vibrato, based on ARP Omni
        ; phaser section.
        ktime1  oscili  .0012 * kvib, 4.2, 1
        ktime2  oscili  .0009 * kvib, 5.3, 1
        ktime3  oscili  .00087 * kvib, 6.1, 1
        ktime4  oscili  .0011 * kvib, 3.9, 1

        ; Each LFO modulates a seperate deltapi delay line.
        adummy  delayr  .015
        asig1   deltapi ktime1 + .009
        asig2   deltapi ktime2 + .009
        asig3   deltapi ktime3 + .009
        asig4   deltapi ktime4 + .009
                delayw  gabajo

        ; The four delay lines are summed together.
        aout = (asig1 + asig2 + asig3 + asig4) * .25

        ; Bandpass filters, set to produce formants for
        ; Cantando u
        afilt1  reson   aout, 350, 40, 1
        afilt2  resonz  aout, 600, 60, 1
        afilt3  resonz  aout, 2700, 100, 1
        afilt4  resonz  aout, 2900, 120, 1
        afilt5  resonz  aout, 3030, 120, 1
        iamp1 = 0
        iamp2 = ampdb(70-20)
        iamp3 = ampdb(70-32)
        iamp4 = ampdb(70-28)
        iamp5 = ampdb(70-36)
        itotal = iamp1+iamp2+iamp3+iamp4+iamp5
        ; porcentaje
        ;ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        ip5 = iamp5 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        aout2 = (afilt1 + ip2 * afilt2 + ip3 * afilt3 + ip4 * afilt4 + ip5 * afilt5)
	aout2 = aout2 * kenv

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        gareverb = gareverb + .47 * aout2

        ; Part of output sent to reverb.
        outs    aout2, aout2

        gabajo = 0

endin



/**************************************************************
			CONSONANTES
**************************************************************/

instr 02 ; La /b/
	ayuda oscil ampdb(p5-28),440,1 ; Seal para ajuste rms
	asal soundin "./samples/b.wav" ; Leemos el fichero

	asal butterlp asal, 4000 ; Filtrado paso-bajo
	asal balance asal, ayuda ; Ajuste rms
	gareverb = gareverb + 0.3*asal ; Envo a la reverb
		outs asal, asal
endin

instr 04 ; La /d/
	ayuda oscil ampdb(p5-22),440,1 ; Seal para ajuste rms
	asal soundin "./samples/d.wav" ; Leemos el fichero

	asal butterlp asal, 4000 ; Filtrado paso-bajo
	asal balance asal, ayuda ; Ajuste rms
	gareverb = gareverb + 0.47*asal ; Envo a la reverb
		outs asal, asal
endin

instr 06 ; La /f/
	ayuda oscil ampdb(p5-34),440,1 ; Seal para ajuste rms
	asal soundin "./samples/f.wav" ; Leemos el fichero
	asal butterlp asal, 3000 ; Filtrado paso-bajo
	kenv expseg 0.1, 0.01*p3, 1, 0.98*p3, 1, 0.01*p3, 0.1
	asal balance asal, ayuda ; Ajuste rms
	asal = asal * kenv
	gareverb = gareverb + 0.47*asal ; Envo a la reverb
		outs asal, asal
endin

instr 07 ; La /g/
	ayuda oscil ampdb(p5-30),440,1 ; Seal para ajuste rms
	asal soundin "./samples/g.wav" ; Leemos el fichero
	asal butterlp asal, 4000 ; Filtrado paso-bajo
	asal balance asal, ayuda ; Ajuste rms
	gareverb = gareverb + 0.47*asal ; Envo a la reverb
		outs asal, asal
endin

instr 10 ; La /j/
	ayuda oscil ampdb(p5-37),440,1 ; Seal para ajuste rms
	asal soundin "./samples/j.wav" ; Leemos el fichero
	kenv expseg 0.1, 0.1*p3, 1, 0.75*p3, 1, 0.15*p3, 0.1
	asal balance asal, ayuda ; Ajuste rms
	asal = asal * kenv
	gareverb = gareverb + 0.47*asal ; Envo a la reverb
		outs asal, asal
endin


instr 11 ; La /k/
	ayuda oscil ampdb(p5-28),440,1 ; Seal para ajuste rms
	asal soundin "./samples/k.wav" ; Leemos el fichero
	asal butterlp asal, 3500 ; Filtrado paso-bajo
	
	kenv expseg 0.01, 0.01*p3, 1, 0.98*p3, 1, 0.01*p3, 0.1
	asal balance asal, ayuda ; Ajuste rms
	asal = asal * kenv
	gareverb = gareverb + 0.47*asal ; Envo a la reverb
		outs asal, asal
endin

instr 12 ; La /l/

        idur = p3
        iamp = ampdb(p5)
        ifreq = cpspch(p4)

        iharms=(sr*.4) / ifreq

	ayuda oscil iamp/8, 440, 1 ; Seal para el ajuste rms
        aout    gbuzz   iamp, ifreq, iharms, 1, .8, 2 ; Seal a filtrar
	
	kenv    linseg  0, .1*idur, 1, idur*0.8, 1, .1*idur, 0 ; Envolvente de amplitud
        
	; Filtrado por formantes:
        afilt_sa1  reson   aout, 517, 80, 1
        afilt_sa2  resonz  aout, 1723, 90, 1
        afilt_sa3  resonz  aout, 2756, 120, 1
        afilt_sa4  resonz  aout, 3747, 130, 1
        
	; Amplitud de cada formante:
        iamp1 = ampdb(70)
        iamp2 = ampdb(70-6)
        iamp3 = ampdb(70-32)
        iamp4 = ampdb(70-20)
	
	; Amplitud total:
       	itotal = iamp1+iamp2+iamp3+iamp4

        ; Porcentaje
        ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        
        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        aout2 = (afilt_sa1 * ip1+ ip2 * afilt_sa2 + ip3 * afilt_sa3 + ip4 * afilt_sa4 )
	aout2 balance aout2, ayuda ; Ajuste de nivel rms
	aout2 = aout2 * kenv ; Aplicacin de la envolvente de amplitud
	gareverb = gareverb + 0.47*aout2 ; Envo a la reverb
		outs aout2, aout2

endin

instr 13 ; La /m/

        idur = p3
        iamp = ampdb(p5)
        ifreq = cpspch(p4)

	ayuda oscil iamp/8, 440, 1 ; Seal para el ajuste rms
        iharms=(sr*.4) / ifreq 

        aout    gbuzz   1, ifreq, iharms, 1, .8, 2 ; Seal a filtrar
 
        kenv    linseg  0, .1*idur, 1, idur*0.8, 1, .1*idur, 0 ; Envolvente de amplitud
        
	; Filtrado por formantes:
	afilt_sa1  reson   aout, 172, 80, 1
        afilt_sa2  resonz  aout, 215, 90, 1
        afilt_sa3  resonz  aout, 1249, 120, 1
        afilt_sa4  resonz  aout, 3531, 130, 1
	
	; Amplitud de cada formante:
        iamp1 = ampdb(70)
        iamp2 = ampdb(70-6)
        iamp3 = ampdb(70-20)
        iamp4 = ampdb(70-32)

	; Amplitud total:
        itotal = iamp1+iamp2+iamp3+iamp4

        ; Porcentaje
        ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal

        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        aout2 = (afilt_sa1 * ip1 + ip2 * afilt_sa2 + ip3 * afilt_sa3 + ip4 * afilt_sa4) 
	aout2 balance aout2, ayuda ; Ajuste de nivel rms
	aout2 = aout2 * kenv ; Envolvente de amplitud
	gareverb = gareverb + 0.47 * aout2 ; Envo a la reverb
		outs aout2, aout2

endin

instr 14 ; La /n/

        idur = p3
        iamp = ampdb(p5)
        ifreq = cpspch(p4)

	ayuda oscil iamp/8, 440, 1 ; Seal para el ajuste rms
        iharms=(sr*.4) / ifreq

        aout    gbuzz   1, ifreq, iharms, 1, .8, 2 ; Seal a filtrar
	kenv    linseg  0, .1*idur, 1, idur*0.8, 1, .1*idur, 0 ; Envolvente de amplitud

	; Filtrado por formantes:
	afilt_sa1  reson   aout, 172, 80, 1
        afilt_sa2  resonz  aout, 0, 90, 1
        afilt_sa3  resonz  aout, 1378, 120, 1
        afilt_sa4  resonz  aout, 2584, 130, 1
	
	; Amplitud de cada formante:
        iamp1 = ampdb(70)
        iamp2 = ampdb(70-6)
        iamp3 = ampdb(70-15)
        iamp4 = ampdb(70-25)
        
	; Amplitud total
	itotal = iamp1+iamp2+iamp3+iamp4
        
	; Porcentaje
        ip1 = iamp1 / itotal
        ip2 = iamp2 / itotal
        ip3 = iamp3 / itotal
        ip4 = iamp4 / itotal
        
        ; Outputs of filters scaled to correspond to relative
        ; amplitudes of formants in vocal sound.
        aout2 = (ip1 * afilt_sa1 + ip2 * afilt_sa2 + ip3 * afilt_sa3 + ip4 * afilt_sa4 )
	aout2 balance aout2, ayuda ; Ajuste rms
	aout2 = aout2 * kenv ; Aplicacin de la envolvente
	gareverb = gareverb +0.47*aout2 ; Envo a la reverb
		outs aout2, aout2

endin

instr 16 ; La /p/
	ayuda oscil ampdb(p5-18),440,1 ; Seal para ajuste rms
	asal soundin "./samples/p.wav" ; Leemos el fichero
	asal butterlp asal, 2500 ; Filtrado paso-bajo

	kenv expseg 0.01, 0.01*p3, 1, 0.98*p3, 1, 0.01*p3, 0.1
	asal balance asal, ayuda ; Ajuste rms
	asal = asal * kenv
	gareverb = gareverb + 0.3*asal ; Envo a la reverb
		outs asal, asal
endin

instr 18 ; La /r/
	ayuda oscil ampdb(p5-30),440,1 ; Seal para ajuste rms
	asal soundin "./samples/r.wav" ; Leemos el fichero
	asal balance asal, ayuda ; Ajuste rms
	gareverb = gareverb + 0.3*asal ; Envo a la reverb
		outs asal, asal
endin

instr 19 ; La /s/
	ayuda oscil ampdb(p5-35),440,1 ; Seal para ajuste rms
	asal soundin "./samples/s.wav" ; Leemos el fichero
	asal butterlp asal, 4000 ; Filtrado paso-bajo
	asal balance asal, ayuda ; Ajuste rms
	gareverb = gareverb + 0.47*asal ; Envo a la reverb
		outs asal, asal
endin

instr 20 ; La /t/
	ayuda oscil ampdb(p5-13),440,1 ; Seal para ajuste rms
	asal soundin "./samples/t.wav" ; Leemos el fichero
	asal butterlp asal, 3000 ; Filtrado paso-bajo
	kenv expseg 0.01, 0.01*p3, 1, 0.75*p3, 1, 0.24*p3, 0.01
	asal balance asal, ayuda ; Ajuste rms
	asal = asal * kenv
	gareverb = gareverb + 0.47*asal ; Envo a la reverb
		outs asal, asal
endin


instr 22 ; La /v/
	ayuda oscil ampdb(p5-25),440,1 ; Seal para ajuste rms
	asal soundin "./samples/b.wav" ; Leemos el fichero

	asal butterlp asal, 3000 ; Filtrado paso-bajo
	kenv expseg 0.01, 0.1*p3, 1, 0.98*p3, 1, 0.01*p3, 0.1
	asal balance asal, ayuda ; Ajuste rms
	;asal = asal * kenv

	gareverb = gareverb + 0.3*asal ; Envo a la reverb
		outs asal, asal
endin


instr 26 ; La /z/
	ayuda oscil ampdb(p5-37),440,1 ; Seal para ajuste rms
	asal soundin "./samples/z.wav" ; Leemos el fichero
	asal butterlp asal, 3500 ; Filtrado paso-bajo
	asal balance asal, ayuda ; Ajuste rms
	gareverb = gareverb + 0.47*asal ; Envo a la reverb
		outs asal, asal
endin

instr 27 ; La /rr/
	ayuda oscil ampdb(p5-25),440,1 ; Seal para ajuste rms
	asal soundin "./samples/rr.wav" ; Leemos el fichero
	asal balance asal, ayuda ; Ajuste rms
	gareverb = gareverb + 0.47*asal ; Envo a la reverb
		outs asal, asal
endin

instr 28 ; La //
	ayuda oscil ampdb(p5-27),440,1 ; Seal para ajuste rms
	asal soundin "./samples/ny.wav" ; Leemos el fichero
	asal balance asal, ayuda ; Ajuste rms
	gareverb = gareverb + 0.47*asal ; Envo a la reverb
		outs asal, asal
endin







; --------------------------- REVERB
instr 9999	; Feedback Delay Network reverb, based on work
		; of Stautner & Puckette.

afilt1 init 0
afilt2 init 0
afilt3 init 0
afilt4 init 0

idur = p3
igain = p4 * 0.70710678117      ; gain of reverb
ipitchmod = p5                  ; amount of random pitch mod, between 0 and 1
idelaytime = p6                 ; controls overall length of delay lines
ifilt = p7                      ; controls cutoff of lowpass filters at outputs of delay lines
ifreq = p8                      ; controls frequency of random noise

;kgain   linseg  .94, 66, .94, 2, 1, p3 - 68, 1
kgain   linen 1, 0.1*idur, idur, 0.01*idur


k1 randi .001, 3.1 * ifreq, .06
k2 randi .0011, 3.5 * ifreq, .9
k3 randi .0017, 1.11 * ifreq, .7
k4 randi .0006, 3.973 * ifreq, .3

atap    multitap gareverb, 0.00043, 0.0215, 0.00268, 0.0298, 0.00485, 0.0572, 0.00595, 0.0708, 0.00741, 0.0797, 0.0142, 0.134, 0.0217, 0.181, 0.0272, 0.192, 0.0379, 0.346, 0.0841, 0.504

adum1 delayr 0.072
adel1 deltapi 0.0663 * idelaytime + k1 * ipitchmod
 delayw gareverb + afilt2 + afilt3

adum2 delayr 0.082
adel2 deltapi 0.0753 * idelaytime + k2 * ipitchmod
 delayw gareverb - afilt1 - afilt4

adum3 delayr 0.095
adel3 deltapi 0.0882 * idelaytime + k3 * ipitchmod
 delayw gareverb + afilt1 - afilt4

adum4 delayr 0.11
adel4 deltapi 0.0971 * idelaytime + k4 * ipitchmod
 delayw gareverb + afilt2 - afilt3

afilt1 tone adel1 * igain * kgain, ifilt
afilt2 tone adel2 * igain * kgain, ifilt
afilt3 tone adel3 * igain * kgain, ifilt
afilt4 tone adel4 * igain * kgain , ifilt

outs afilt1 + afilt4 + atap, afilt2 + afilt3 + atap

gareverb = 0

endin
